@@ -1,3 +1,4 @@
+#! /usr/bin/env python3
 # -*- coding: utf-8 -*-
 
 # Copyright 2020 Google LLC
@@ -40,22 +41,23 @@ def partition(
 class cloudbuildCallTransformer(cst.CSTTransformer):
     CTRL_PARAMS: Tuple[str] = ('retry', 'timeout', 'metadata')
     METHOD_TO_PARAMS: Dict[str, Tuple[str]] = {
-    'cancel_build': ('project_id', 'id', ),
-    'create_build': ('project_id', 'build', ),
+    'cancel_build': ('project_id', 'id', 'name', ),
+    'create_build': ('project_id', 'build', 'parent', ),
     'create_build_trigger': ('project_id', 'trigger', ),
     'create_worker_pool': ('parent', 'worker_pool', ),
     'delete_build_trigger': ('project_id', 'trigger_id', ),
     'delete_worker_pool': ('name', ),
-    'get_build': ('project_id', 'id', ),
+    'get_build': ('project_id', 'id', 'name', ),
     'get_build_trigger': ('project_id', 'trigger_id', ),
     'get_worker_pool': ('name', ),
-    'list_builds': ('project_id', 'page_size', 'page_token', 'filter', ),
+    'list_builds': ('project_id', 'parent', 'page_size', 'page_token', 'filter', ),
     'list_build_triggers': ('project_id', 'page_size', 'page_token', ),
     'list_worker_pools': ('parent', ),
-    'retry_build': ('project_id', 'id', ),
+    'retry_build': ('project_id', 'id', 'name', ),
     'run_build_trigger': ('project_id', 'trigger_id', 'source', ),
     'update_build_trigger': ('project_id', 'trigger_id', 'trigger', ),
     'update_worker_pool': ('name', 'worker_pool', ),
+
     }
 
     def leave_Call(self, original: cst.Call, updated: cst.Call) -> cst.CSTNode:
